@@ -22,8 +22,8 @@ import wsgi_fileserver
 def setup_module(module):
     windmill.authoring.setup_module(module)
 
-    application = wsgi_fileserver.WSGIFileServerApplication(root_path=os.path.dirname(__file__), mount_point='/windmill-unittests/')
+    application = wsgi_fileserver.WSGIFileServerApplication(root_path=os.path.abspath(os.path.dirname(__file__)), mount_point='/windmill-unittests/')
     windmill.server.wsgi.add_namespace('windmill-unittests', application)
     
 from windmill.authoring import teardown_module
-    
\ No newline at end of file
+    
