@@ -1,4 +1,5 @@
 #   Copyright (c) 2006-2007 Open Source Applications Foundation
+#   Copyright (c) 2008-2009 Mikeal Rogers <mikeal.rogers@gmail.com>
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -165,6 +166,31 @@ class NoCompress(GeneralBoolSettingToTrue):
     option_names = (None, 'nocompress')
     setting = "DISABLE_JS_COMPRESS"
     
+class SSL(GeneralBool):
+    """Enable SSL support."""
+    option_names = (None, 'ssl')
+    def __call__(self, value=None):
+        import windmill
+        try:
+            import OpenSSL
+            windmill.has_ssl = True
+        except ImportError:
+            print "*" * 60
+            print "*** HTTPS Support is disabled, as PyOpenSSL was not found."
+            print "*** Please install PyOpenSSL."
+            print "*" * 60
+            windmill.has_ssl = False
+            
+        if 'ie' in sys.argv or 'safari' in sys.argv or 'chrome' in sys.argv:
+            print "*" * 60
+            print "* Windmill cannot automatically install the Certificate Authority."
+            print "* You will need to do this manually, the process is fully documented."
+            if sys.platform in ('win32', 'cygwin'): 
+                print "* http://trac.getwindmill.com/wiki/SSL#InstallingCAonWindows"
+            else:
+                print "* http://trac.getwindmill.com/wiki/SSL#InstallingCAonMacOSX"
+            print "*" * 60
+    
 class Port(object):
     """Set port for windmill to run. Default is 4444."""
     option_names = (None, 'port')
