@@ -1,4 +1,5 @@
 #   Copyright (c) 2007 Open Source Applications Foundation
+#   Copyright (c) 2008-2009 Mikeal Rogers <mikeal.rogers@gmail.com>
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -12,7 +13,10 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 
-import simplejson
+try:
+    import json as simplejson
+except:
+    import simplejson
 import sys, os
 from windmill.authoring import transforms
 
