@@ -1,4 +1,6 @@
 #   Copyright (c) 2006-2007 Open Source Applications Foundation
+#   Copyright (c) 2008-2009 Mikeal Rogers <mikeal.rogers@gmail.com>
+#   Copyright (c) 2009 Domen Kozar <domen@dev.si>
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -13,10 +15,18 @@
 #   limitations under the License.
 
 import windmill
-from urlparse import urlparse
+import sys
+import copy
+from pkg_resources import resource_string
 
 import os
 
+if not sys.version.startswith('2.4'):
+    from urlparse import urlparse
+else:
+    # python 2.4
+    from windmill.tools.urlparse_25 import urlparse
+
 windmill.browser_registry = {}
 
 def get_firefox_controller():
@@ -36,9 +46,9 @@ def get_firefox_controller():
     
     if windmill.settings['INSTALL_FIREBUG']:
         windmill.settings['MOZILLA_PLUGINS'] = [os.path.join(os.path.dirname(__file__), os.path.pardir, 'xpi', 'firebug-1.2.1-fx.xpi')]
-            
-    windmill.settings['MOZILLA_PREFERENCES'].update( {
-        'extensions.chromebug.openalways' : True,
+    
+    prop_hash = {
+                'extensions.chromebug.openalways' : True,
         'extensions.chromebug.showIntroduction' : False,
         'general.warnOnAboutConfig' : False,
         'extensions.venkman.enableChromeFilter' : False,
@@ -60,13 +70,13 @@ def get_firefox_controller():
         #"network.http.proxy.pipelining" : True,
         "network.http.max-connections": 10,
         "network.http.max-connections-per-server": 8,
-#        "network.http.max-persistent-connections-per-proxy": 2,
-#        "network.http.max-persistent-connections-per-server": 2,
+    #        "network.http.max-persistent-connections-per-proxy": 2,
+    #        "network.http.max-persistent-connections-per-server": 2,
         "network.http.pipelining.maxrequests": 10,
-        
+
         # Turn off favicon requests, no need for even more requests
         "browser.chrome.favicons": False,
-        
+
         "startup.homepage_override_url": test_url,
         "browser.startup.homepage": test_url,
         "startup.homepage_welcome_url": "",
@@ -92,12 +102,29 @@ def get_firefox_controller():
         "security.OCSP.enabled":0,
         #Make the firefox IDE stop showing the location bar
         "dom.disable_window_open_feature.location":False,
-        } )
+    }
+    
+    if windmill.has_ssl:
+         prop_hash["network.proxy.ssl"] = 'localhost'
+         prop_hash["network.proxy.ssl_port"] = windmill.settings['SERVER_HTTP_PORT']
+       
+    windmill.settings['MOZILLA_PREFERENCES'].update(prop_hash)
         
     windmill.settings['MOZILLA_CMD_ARGS'] = [test_url]
     
-    controller = mozrunner.get_moz_from_settings(windmill.settings)
-    
+    controller = mozrunner.get_moz_from_settings(copy.copy(windmill.settings))
+
+    # Override cert8.db with one from windmill which has windmill certificate
+    # in it, that way self-signed certificate warning is suppressed.
+    cert8 = resource_string(__name__, 'cert8.db')
+    if sys.platform not in ('win32', 'cygwin',):
+        f = open(os.path.join(controller.profile, 'cert8.db'), 'w')        
+    else:
+        f = open(os.path.join(controller.profile, 'cert8.db'), 'wb')
+        
+    f.write(cert8)
+    f.close()    
+    windmill.settings['MOZILLA_PROFILE'] = mozrunner.settings['MOZILLA_PROFILE']
     return controller
     
 def get_ie_controller():
@@ -117,4 +144,4 @@ def get_chrome_controller():
     import chrome
     browser = chrome.Chrome()
     return browser
-    
\ No newline at end of file
+    
