@@ -1,10 +1,29 @@
+#   Copyright (c) 2009 Mikeal Rogers <mikeal.rogers@gmail.com>
+#   Copyright (c) 2009 Domen Kozar <domen@dev.si>
+#
+#   Licensed under the Apache License, Version 2.0 (the "License");
+#   you may not use this file except in compliance with the License.
+#   You may obtain a copy of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#   Unless required by applicable law or agreed to in writing, software
+#   distributed under the License is distributed on an "AS IS" BASIS,
+#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#   See the License for the specific language governing permissions and
+#   limitations under the License.
+
 import commands
 import tempfile
 import logging
 import signal
 import subprocess
 import sys, os
-import urlparse
+if not sys.version.startswith('2.4'):
+    from urlparse import urlparse
+else:
+    # python 2.4
+    from windmill.tools.urlparse_25 import urlparse
 
 import windmill	
 
@@ -64,7 +83,12 @@ class Chrome(safari.Safari):
 	    if sys.platform in ('cygwin', 'win32'):
 	        self.set_proxy_windows()
 	    
-	    kwargs = {'stdout':sys.stdout ,'stderr':sys.stderr, 'stdin':sys.stdin}
+	    # Workaround for bug in nose
+	    if hasattr(sys.stdout, 'fileno'):
+	        kwargs = {'stdout':sys.stdout ,'stderr':sys.stderr, 'stdin':sys.stdin}
+	    else:
+	        kwargs = {'stdout':sys.__stdout__ ,'stderr':sys.__stderr__, 'stdin':sys.stdin}
+	    
 	    command = [self.chrome_binary, '--homepage', self.test_url+'/windmill-serv/start.html', '-disable-popup-blocking']
 	    self.p_handle = subprocess.Popen(command, **kwargs)
 	    logger.info(command)
