@@ -1,10 +1,32 @@
+#   Copyright (c) 2008-2009 Mikeal Rogers <mikeal.rogers@gmail.com>
+#   Copyright (c) 2009 Domen Kozar <domen@dev.si>
+#
+#   Licensed under the Apache License, Version 2.0 (the "License");
+#   you may not use this file except in compliance with the License.
+#   You may obtain a copy of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#   Unless required by applicable law or agreed to in writing, software
+#   distributed under the License is distributed on an "AS IS" BASIS,
+#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#   See the License for the specific language governing permissions and
+#   limitations under the License.
+
 import commands
 import tempfile
 import logging
 import signal
 import killableprocess
+import subprocess
 import sys, os
-import urlparse
+if not sys.version.startswith('2.4'):
+    import urlparse
+else:
+    # python 2.4
+    from windmill.tools import urlparse_25 as urlparse
+
+from StringIO import StringIO
 
 import windmill	
 
@@ -43,22 +65,44 @@ html_redirection = """
   </body>
 <html>"""
 
+def getoutput(l):
+    tmp = tempfile.mktemp()
+    x = open(tmp, 'w')
+    subprocess.call(l, stdout=x, stderr=x)
+    x.close(); x = open(tmp, 'r')
+    r = x.read() ; x.close()
+    os.remove(tmp)
+    return r
+
+def dprint(s):
+    if len(s) is not 0:
+        print s.rstrip('\n')
+    if 'Library/Preferences/SystemConfiguration/preferences.plist.old' in s:
+        print "** To remove this error `chmod -R 777` the directory that shows the permission error"
 
 def find_default_interface_name():
     if windmill.settings['NETWORK_INTERFACE_NAME'] is not None:
         return windmill.settings['NETWORK_INTERFACE_NAME']
     target_host = urlparse.urlparse(windmill.settings['TEST_URL']).hostname
-    interface_id = commands.getoutput('route get '+target_host).split('interface:')[1].split('\n')[:1][0].replace(' ', '')
-    all_inet = commands.getoutput(windmill.settings['NETWORKSETUP_BINARY']+' -listallhardwareports').split('\n\n')
+    x = ['/sbin/route', 'get', target_host]
+    interface_id = [l for l in getoutput(x).splitlines() if 'interface' in l][0].split(":")[-1].strip()
+    all_inet = getoutput([windmill.settings['NETWORKSETUP_BINARY'], '-listallhardwareports']).splitlines()
     try:
-        interface_name = [ l for l in all_inet if l.find(interface_id) is not -1 ][0].split('\n')[0].split(' ')[-1]
+        i = all_inet.index([l for l in all_inet if 'Device: '+interface_id in l][0])
+        interface_name = all_inet[i - 1].split(':')[-1].strip()
+
+        # interface_name = [ l for l in all_inet if l.find(interface_id) is not -1 ][0].split('\n')[0].split(':')[-1]
+        # if interface_name[0] == ' ':
+        #     interface_name = interface_name.strip()
+        # if interface_name[-1] == ' ':
+        #     interface_name = interface_name.rstrip()
     except IndexError:
         print "ERROR: Cannot figure out interface name, please set NETWORK_INTERFACE_NAME in local settings file"
         from windmill.bin import admin_lib
         admin_lib.teardown(admin_lib.shell_objects_dict)
         sys.exit()
     
-    # interfaces = commands.getoutput().split('\n\n')
+    # interfaces = getoutput().split('\n\n')
     # print 'interfaces::\n', '\n'.join(interfaces)
     # for line in interfaces:
     #     if not line.startswith('(') and line.find('(1)') is not -1:
@@ -86,24 +130,34 @@ class Safari(object):
 	    self.netsetup_binary = windmill.settings['NETWORKSETUP_BINARY']
 	    interface_name = find_default_interface_name()
 	    uri = urlparse.urlparse(self.test_url)
-	    set_proxy_command = ' '.join([ self.netsetup_binary, 
-	                                   '-setwebproxy', 
-	                                   '"'+interface_name+'"', 
-	                                   'localhost', 
-	                                   str(windmill.settings['SERVER_HTTP_PORT'])
-	                                 ])
-	    commands.getoutput(set_proxy_command)
-	    enable_proxy_command = ' '.join([ self.netsetup_binary,
-	                                      '-setwebproxystate',
-	                                      '"'+interface_name+'"',
-	                                      'on'
-	                                    ])
-	    commands.getoutput(enable_proxy_command)	    
+	    set_proxy_command = [ self.netsetup_binary, '-setwebproxy', 
+	                          interface_name, 'localhost', 
+	                          str(windmill.settings['SERVER_HTTP_PORT'])
+	                        ]
+	    dprint(getoutput(set_proxy_command))
+	    
+	    enable_proxy_command = [ self.netsetup_binary, '-setwebproxystate',
+	                             interface_name, 'on'
+	                           ]
+	    dprint(getoutput(enable_proxy_command))
+	    if windmill.has_ssl:
+	        set_ssl_proxy_command = [ self.netsetup_binary, '-setsecurewebproxy', 
+    	                              interface_name, 'localhost', 
+    	                              str(windmill.settings['SERVER_HTTP_PORT'])
+    	                            ]
+    	    dprint(getoutput(set_proxy_command))
+    	    enable_ssl_proxy_command = [ self.netsetup_binary, '-setsecurewebproxystate',
+    	                                 interface_name, 'on'
+    	                               ]
+    	    dprint(getoutput(enable_proxy_command))
+	    
+	        
 	    self.create_redirect()
 	    self.interface_name = interface_name
 	
 	def unset_proxy_mac(self):
-	    commands.getoutput(' '.join([self.netsetup_binary, '-setwebproxystate', '"'+self.interface_name+'"', 'off']))
+	    getoutput([self.netsetup_binary, '-setwebproxystate', self.interface_name, 'off'])
+	    getoutput([self.netsetup_binary, '-setsecurewebproxystate', self.interface_name, 'off'])
 	
 	def set_proxy_windows(self):
 	    self.create_redirect()
@@ -120,8 +174,11 @@ class Safari(object):
 	        self.set_proxy_mac()
 	    elif sys.platform in ('cygwin', 'win32'):
 	        self.set_proxy_windows()
-	    
-	    kwargs = {'stdout':sys.stdout ,'stderr':sys.stderr, 'stdin':sys.stdin}
+	    # Workaround for bug in nose
+	    if hasattr(sys.stdout, 'fileno'):
+	        kwargs = {'stdout':sys.stdout ,'stderr':sys.stderr, 'stdin':sys.stdin}
+	    else:
+	        kwargs = {'stdout':sys.__stdout__ ,'stderr':sys.__stderr__, 'stdin':sys.stdin}
 	    self.p_handle = killableprocess.runCommand([self.safari_binary, self.redirection_page], **kwargs)
 	    logger.info([self.safari_binary, self.redirection_page])
 
