@@ -20,62 +20,51 @@ windmill.controller.what = function() {
   alert('Internet Explorer');
 }
 
-/**
- * In IE, getElementById() also searches by name - this is an optimisation for IE.
- */
-windmill.controller.locateElementByIdentifer = function(identifier, inDocument, inWindow) {
-  return inDocument.getElementById(identifier);
-};
-  
-windmill.controller.click = function(param_object){        
-   var element = this._lookupDispatch(param_object);
-    if (!element){ return false; }
-    windmill.events.triggerEvent(element, 'focus', false);
+windmill.controller.click = function(paramObject){        
+  var element = lookupNode(paramObject);
+  windmill.events.triggerEvent(element, 'focus', false);
 
-    // And since the DOM order that these actually happen is as follows when a user clicks, we replicate.
-    try {windmill.events.triggerMouseEvent(element, 'mousedown', true); } catch(err){}
-    try {windmill.events.triggerMouseEvent(element, 'mouseup', true); } catch(err){}
-    try {windmill.events.triggerMouseEvent(element, 'click', true); } catch(err){}
+  // And since the DOM order that these actually happen is as follows when a user clicks, we replicate.
+  //try {windmill.events.triggerMouseEvent(element, 'mousedown', true); } catch(err){}
+  //try {windmill.events.triggerMouseEvent(element, 'mouseup', true); } catch(err){}
+  windmill.controller.mouseDown(paramObject);
+  windmill.controller.mouseUp(paramObject);
+  
+    if (paramObject.options){
+      var arr = paramObject.options.split(',');
+      arr.unshift(element, 'click', true, null, null);
+      try { windmill.events.triggerMouseEvent.apply(this, arr); } catch(err){}
+    }
+    else { 
+      try {windmill.events.triggerMouseEvent(element, 'click', true); } catch(err){}  
+    }
   
-   return true;
 };
   
 //there is a problem with checking via click in safari
-windmill.controller.check = function(param_object){
-  return windmill.controller.click(param_object);
+windmill.controller.check = function(paramObject){
+  return windmill.controller.click(paramObject);
 }
 
 //Radio buttons are even WIERDER in safari, not breaking in FF
-windmill.controller.radio = function(param_object){
-    //var element = this._lookupDispatch(param_object);
-    return windmill.controller.click(param_object);
+windmill.controller.radio = function(paramObject){
+  return windmill.controller.click(paramObject);
 }
   
 //double click for ie
-windmill.controller.doubleClick = function(param_object){      
-   var element = this._lookupDispatch(param_object);
-   if (!element){
-     return false;
-   }
+windmill.controller.doubleClick = function(paramObject){      
+   var element = lookupNode(paramObject);
    windmill.events.triggerEvent(element, 'focus', false);
-
-     // Trigger the mouse event.
-     //windmill.events.triggerMouseEvent(element, 'dblclick', true, clientX, clientY);
-     windmill.events.triggerMouseEvent(element, 'dblclick', true);   
-   /* if (this.windowClosed()) {
-         return;
-     }*/
-     windmill.events.triggerEvent(element, 'blur', false);       
-  return true;
+   // Trigger the mouse event.
+   windmill.events.triggerMouseEvent(element, 'dblclick', true);   
+   windmill.events.triggerEvent(element, 'blur', false);       
 };
  
 //Type Function
- windmill.controller.type = function (param_object){
+ windmill.controller.type = function (paramObject){
+
+   var element = lookupNode(paramObject);
 
-   var element = this._lookupDispatch(param_object);
-   if (!element){
-     return false;
-   }
    //clear the box
    element.value = '';
    //Get the focus on to the item to be typed in, or selected
@@ -84,8 +73,8 @@ windmill.controller.doubleClick = function(param_object){
     
    //Make sure text fits in the textbox
    var maxLengthAttr = element.getAttribute("maxLength");
-   var actualValue = param_object.text;
-   var stringValue = param_object.text;
+   var actualValue = paramObject.text;
+   var stringValue = paramObject.text;
     
    if (maxLengthAttr != null) {
      var maxLength = parseInt(maxLengthAttr);
@@ -102,10 +91,12 @@ windmill.controller.doubleClick = function(param_object){
      windmill.events.triggerKeyEvent(element, 'keypress', s.charAt(c), true, false,false, false,false); 
      windmill.events.triggerKeyEvent(element, 'keyup', s.charAt(c), true, false,false, false,false);
    }
+    //if for some reason the key events don't do the typing
+    if (element.value != s){
+      element.value = s;
+    }
     
    // DGF this used to be skipped in chrome URLs, but no longer.  Is xpcnativewrappers to blame?
    //Another wierd chrome thing?
    windmill.events.triggerEvent(element, 'change', true);
-    
-   return true;
  };
