@@ -90,13 +90,9 @@ windmill.events = new function() {
     this.triggerEvent = function(element, eventType, canBubble, controlKeyDown, altKeyDown, shiftKeyDown, metaKeyDown) {
 
         canBubble = (typeof(canBubble) == undefined) ? true: canBubble;
-        if (element.fireEvent) {
-            //alert(eventType)
+        if (element.fireEvent && windmill.browser.isIE) {
             var evt = windmill.events.createEventObject(element, controlKeyDown, altKeyDown, shiftKeyDown, metaKeyDown);
             element.fireEvent('on' + eventType, evt);
-            //Fix for IE6-- this does work but isn't needed the bug was in the type function
-            //eval("element." + eventType + "();");
-
         }
         else {
             var evt = document.createEvent('HTMLEvents');
@@ -131,14 +127,15 @@ windmill.events = new function() {
             return match[0];
 
         }
-        windmill.ui.results.writeResult("invalid keySequence");
+        windmill.err("invalid keySequence");
 
     }
 
     this.triggerKeyEvent = function(element, eventType, keySequence, canBubble, controlKeyDown, altKeyDown, shiftKeyDown, metaKeyDown) {
         var keycode = windmill.events.getKeyCodeFromKeySequence(keySequence);
         canBubble = (typeof(canBubble) == undefined) ? true: canBubble;
-        if (element.fireEvent) {
+        //Make sure we don't call fireEvent otuside of IE, mootools adds this to the prototype
+        if (element.fireEvent && windmill.browser.isIE) {
             var keyEvent = windmill.events.createEventObject(element, controlKeyDown, altKeyDown, shiftKeyDown, metaKeyDown);
             keyEvent.keyCode = keycode;
             element.fireEvent('on' + eventType, keyEvent);
@@ -177,7 +174,7 @@ windmill.events = new function() {
 
         canBubble = (typeof(canBubble) == undefined) ? true: canBubble;
 
-        if (element.fireEvent) {
+        if (element.fireEvent && windmill.browser.isIE) {
             //LOG.info("element has fireEvent");
             var evt = windmill.events.createEventObject(element, controlKeyDown, altKeyDown, shiftKeyDown, metaKeyDown);
             evt.detail = 0;
@@ -199,7 +196,7 @@ windmill.events = new function() {
                 // ideally we could just slide it in as follows in the try-block below, but this normally
                 // doesn't work.  This is why I try to avoid this code path, which is only required if we need to
                 // set attributes on the event (e.g., clientX).
-                try { _w.event = evt; }
+                try { windmill.testWin().event = evt; }
                 catch(e) {
                     // getting an "Object does not support this action or property" error.  Save the event away
                     // for future reference.
