@@ -21,10 +21,13 @@ windmill.jsTest = new function () {
   var _this = this;
   // Private vars
   var _UNDEF; // Undefined val
+  var _OBJ_LOOKUP_RETRY_LIMIT = 10;
+
   var _debug = false;
   var _currentTestTimer;
   var _testsPaused = false;
   var _brokenEval;
+  var _objLookupRetries = 0;
   var _testItemArrayObj;
   var serverBasePath = '';
   var jsFilesBasePath = '';
@@ -33,6 +36,19 @@ windmill.jsTest = new function () {
   var testPhases = '';
   var testListReverseMap = {};
   var _ieDebugger;
+  var _timerCode =
+    '      windmill.jsTest.Timer = function () {' +
+    '        this.startTime = null;' +
+    '        this.endTime = null;' +
+    '        this.time = null;' +
+    '        this.start = function () {' +
+    '          this.startTime = new Date().getTime();' +
+    '        };' +
+    '        this.finish = function () {' +
+    '          this.endTime = new Date().getTime();' +
+    '          this.time = this.endTime - this.startTime;' +
+    '        };' +
+    '      };';
 
   var _log = function (s) {
     if (_debug) {
@@ -319,23 +335,10 @@ windmill.jsTest = new function () {
     testFilter = paramObj.filter || null;
     testPhases = paramObj.phase || null;
 
-    for (var i = 0; i < testFiles.length; i++) {
-      var t = testFiles[i];
-      if (t.indexOf('/register.js') > -1) {
-        regIndex = i;
-      }
-    }
-    // Get any specific test registrations
-    // Exec this file in the remote's window scope
-    // to call registerTests or registerTestNamespace
-    if (typeof regIndex == 'number') {
-      this.regFile = true;
-      var regPath = testFiles[regIndex];
-      testFiles.splice(regIndex, 1);
-      this.doTestRegistration(regPath);
-    }
     // Remove any directories or non-js files returned
+    var t;
     for (var i = 0; i < testFiles.length; i++) {
+      t = testFiles[i];
       if (t.indexOf('\.js') == -1) {
         _this.sendJSReport('(Loading of test code)', false, null, new windmill.TimeObj());
         _this.teardown();
@@ -347,26 +350,6 @@ windmill.jsTest = new function () {
     this.testFiles = testFiles;
     return true;
   };
-  // Grab any ordered list of tests to run if register.js exists
-  this.doTestRegistration = function(path) {
-    var str = this.getFile(path);
-    // Eval in window scope
-    globalEval(path, str, false);
-    return true;
-  };
-  // Can be called from the eval of an register.js file --
-  // registers all the tests to be run, in order
-  this.registerTests = function (arr) {
-    this.testNamespaces = combineLists(this.testNamespaces, arr);
-  };
-  // Can be called from the eval of a register.js file --
-  // parses a JS namespace object for functions that
-  // start with 'test_'. Does not *guarantee* the order of
-  // tests run, but all existing ECMAScript implementations
-  // actually do a for/in in the order properties are added
-  this.registerTestNamespace = function (name) {
-    this.testNamespaces.push(name);
-  };
   // Grab the contents of the test files, and eval
   // them in window scope
   this.loadTestFiles = function () {
@@ -376,17 +359,14 @@ windmill.jsTest = new function () {
     jsFilesBasePath = serverBasePath + '/windmill-jstest/';
 
     // Create a ref to the windmill object in the testing app
-    try {
-      windmill.testWin().windmill = windmill;
-    } catch (err){
-      windmill.testWin().windmill = windmill;
-    }
-
+    windmill.testWin().windmill = windmill;
     // Load the asserts into the test window scope
     // as the 'jum' object
-    if (this.runInTestWindowScope) {
-      windmill.testWin().jum = windmill.controller.asserts;
-    }
+    windmill.testWin().jum = windmill.controller.asserts;
+    // Create the timer object down in the test
+    // window using global eval so IE can
+    // recognize it as a function
+    globalEval('<private var _timerCode string value>', _timerCode, true);
 
     loadedJSCodeFiles = {};
     // The aggregated source code for the tests
@@ -707,7 +687,19 @@ windmill.jsTest = new function () {
     }
     return ret;
   };
-  this.runNextTest = function () {
+  // Delegate to a method called on a setTimeout to give the
+  // UI thread time to fire onbeforeunload event when leaving
+  // the current page, and set the testCodeState to CANNOT_LOAD
+  // Without this, the test engine can end up trying to run
+  // the next test before it notices the test code on the page
+  // has been unloaded
+  this.runNextTest = function (retryTestName) {
+    timeout = !!retryTestName ? 1000 : 0;
+    setTimeout(function () {
+        _this.runNextTestFreeUiThread.call(_this, retryTestName); },
+            timeout);
+  };
+  this.runNextTestFreeUiThread = function (retryTestName) {
     _log('Starting runNextTest.');
     var testName = '';
     var testItem = null;
@@ -729,7 +721,7 @@ windmill.jsTest = new function () {
         return false;
       }
       // Get the test name
-      testName = this.testOrder.shift();
+      testName = retryTestName || this.testOrder.shift();
 
       // Test-run timing
       var timer = new windmill.TimeObj();
@@ -737,23 +729,38 @@ windmill.jsTest = new function () {
       timer.startTime();
       _currentTestTimer = timer;
 
-      // Need to separate scope and executable in cases
-      // where testable is an executable function because
-      // waits occur in a setTimeout loop that breaks scope
-      // -----------
-      // Namespaced testables
-      if (testName.indexOf('.') > -1) {
-        var testNameArr = testName.split('.');
-        var testNameKey = testNameArr.pop();
-        var testScope = testNameArr.join('.');
-        testScope = this.lookupObjRef(testScope);
-        testItem = testScope[testNameKey];
+      try {
+        // Need to separate scope and executable in cases
+        // where testable is an executable function because
+        // waits occur in a setTimeout loop that breaks scope
+        // -----------
+        // Namespaced testables
+        if (testName.indexOf('.') > -1) {
+          var testNameArr = testName.split('.');
+          var testNameKey = testNameArr.pop();
+          var testScope = testNameArr.join('.');
+          testScope = this.lookupObjRef(testScope);
+          testItem = testScope[testNameKey];
+        }
+        // Top-level, global-named testables
+        else {
+          testScope = this.getCurrentTestScope();
+          testItem = this.lookupObjRef(testName);
+        }
       }
-      // Top-level, global-named testables
-      else {
-        testScope = this.getCurrentTestScope();
-        testItem = this.lookupObjRef(testName);
+      catch (e) {
+        if (_objLookupRetries > _OBJ_LOOKUP_RETRY_LIMIT) {
+          _objLookupRetries = 0;
+          throw (e);
+        }
+        else {
+          _objLookupRetries++;
+          this.runNextTest(testName);
+          return;
+        }
       }
+      _objLookupRetries = 0;
+
       // Tell IDE what is going on -- if the string is really
       // long and namespaced, just use the functions name
       var testNameArr = testName.split(".");
@@ -1112,10 +1119,6 @@ windmill.jsTest = new function () {
       s += '</div>';
     }
     windmill.out(s);
-    //We want the summary to have a concept of success/failure
-    var result = !(this.testFailureCount > 0);
-    var method = 'JS Test Suite Completion';
-    this.sendJSReport(method, result, null, this.jsSuiteSummary);
   };
 };
 
