@@ -17,7 +17,6 @@ Copyright 2006-2007, Open Source Applications Foundation
 var windmill = new function() {
 
     //More namespacing
-    this.builder = {};
     this.helpers = {};
 
     //The timeout for page loading, if the onload is never called
@@ -69,7 +68,6 @@ var windmill = new function() {
     this.varRegistry = new fleegix.hash.Hash();
 
     //The app your testing
-    this.testWindowStr = 'windmill.testWindow';
     this.testWindow = opener;
     this.initialHost = '';
     
@@ -247,14 +245,14 @@ var windmill = new function() {
     
     this.attachUnload = function(w){
        if (!windmill.browser.isIE){
-          fleegix.event.unlisten(windmill.testWin(), 'onunload', windmill, 'unloaded');
-          fleegix.event.listen(windmill.testWin(), 'onunload', windmill, 'unloaded');
+          fleegix.event.unlisten(windmill.testWin(), 'onbeforeunload', windmill, 'unloaded');
+          fleegix.event.listen(windmill.testWin(), 'onbeforeunload', windmill, 'unloaded');
         }
       else {
         try {
-          w.detachEvent("onunload", windmill.unloaded);
+          w.detachEvent("onbeforeunload", windmill.unloaded);
         } catch(err){}
-        w.attachEvent("onunload", windmill.unloaded)
+        w.attachEvent("onbeforeunload", windmill.unloaded)
       }
     };
     
@@ -323,7 +321,9 @@ var windmill = new function() {
         //If the doc domain has changed
         //and we can't get to it, try updating it
         try{ var v = windmill.testWin().document.domain; }
-        catch(err){ document.domain = windmill.docDomain; }
+        catch(err){
+//          document.domain = windmill.docDomain; 
+        }
 
         //Overwrite alerts to keep the browser from getting stuck
         //on by default
