@@ -1,4 +1,5 @@
 #   Copyright (c) 2006-2007 Open Source Applications Foundation
+#   Copyright (c) 2008-2009 Mikeal Rogers <mikeal.rogers@gmail.com>
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -14,7 +15,12 @@
 
 import wsgi, convergence
 
-forwarding_conditions = [lambda e : 'google.com/safebrowsing/downloads' not in e['reconstructed_url']]
+forwarding_conditions = [
+    lambda e : 'google.com/safebrowsing/downloads' not in e['reconstructed_url'],
+    lambda e : 'mozilla.org/en-US/firefox/livebookmarks.html' not in e['reconstructed_url'],
+    lambda e : e.get('CONTENT_TYPE') != 'application/x-shockwave-flash',
+    lambda e : not e['reconstructed_url'].endswith(".mozilla.com/firefox/headlines.xml")
+    ]
 
 def add_forward_condition(condition):
     forwarding_conditions.append(condition)
