@@ -1,4 +1,6 @@
 #   Copyright (c) 2006-2007 Open Source Applications Foundation
+#   Copyright (c) 2008-2009 Mikeal Rogers <mikeal.rogers@gmail.com>
+#   Copyright (c) 2009 Domen Kozar <domen@dev.si>
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -20,10 +22,15 @@ import copy
 import socket 
 import random
 import os
-from urlparse import urlparse
 import logging
 import threading
+import sys
 from time import sleep
+if not sys.version.startswith('2.4'):
+    from urlparse import urlparse
+else:
+    # python 2.4
+    from windmill.tools.urlparse_25 import urlparse
 logger = logging.getLogger(__name__)
 
 import windmill
@@ -85,7 +92,7 @@ class WindmillChooserApplication(object):
         sleep(.2)
         reconstruct_url(environ)
 
-        for key in self.namespaces.keys():
+        for key in self.namespaces:
             if environ['PATH_INFO'].find('/'+key+'/') is not -1:
                 logger.debug('dispatching request %s to %s' % (environ['reconstructed_url'], key))
                 return self.namespaces[key](environ, start_response)
@@ -102,19 +109,15 @@ class WindmillChooserApplication(object):
 class WindmillCompressor(object):
     """Full JavaScript Compression Library"""
     js_file_list = [
-        ('lib', 'fleegix.js',),
-        ('lib', 'hash.js',),
-        ('lib', 'pi.js',),
-        ('lib', 'firebug-lite.js',),
+        ('lib', 'fleegix_js', 'plugins', 'hash.js',),
+        ('lib', 'firebug', 'pi.js',),
+        ('lib', 'firebug', 'firebug-lite.js',),
         ('lib', 'json2.js',),
         ('lib', 'browserdetect.js',),
         ('wm', 'windmill.js',),
         ('lib', 'getXPath.js',),
         ('lib', 'elementslib.js',),
-        ('lib', 'ajaxslt', 'xmltoken.js',),
-        ('lib', 'ajaxslt', 'dom.js',),
-        ('lib', 'ajaxslt', 'util.js',),
-        ('lib', 'ajaxslt', 'xpath.js',),
+        ('lib', 'js-xpath.js',),
         ('controller', 'controller.js',),
         ('controller', 'commands.js',),
         ('controller', 'asserts.js',),
@@ -173,7 +176,7 @@ def make_windmill_server(http_port=None, js_path=None, compression_enabled=None)
     if js_path is None:
         js_path = windmill.settings['JS_PATH']
     if compression_enabled is None:
-        compression_enabled = windmill.settings['COMPRESS_JS']
+        compression_enabled = not windmill.settings['DISABLE_JS_COMPRESS']
         
     # Start up all the convergence objects    
     import convergence
@@ -193,17 +196,19 @@ def make_windmill_server(http_port=None, js_path=None, compression_enabled=None)
     windmill_xmlrpc_app.ns = 'windmill-xmlrpc'
     windmill_jsonrpc_app.ns = 'windmill-jsonrpc'
     windmill_compressor_app.ns = 'windmill-compressor'
-    windmill_chooser_app = WindmillChooserApplication(apps=[windmill_serv_app, windmill_jsonrpc_app,
-                                                            windmill_xmlrpc_app, windmill_compressor_app],
-                                                      proxy=windmill_proxy_app)
-    
-    # Make add_namespace available at the module level
     global add_namespace
-    add_namespace = windmill_chooser_app.add_namespace
-    
-    from cherrypy import wsgiserver
-    httpd = wsgiserver.CherryPyWSGIServer(('0.0.0.0', http_port), 
-                       windmill_chooser_app, server_name='windmill-http', numthreads=50)
+    import https
+    if windmill.has_ssl:
+        import certificate
+        cc = certificate.CertificateCreator()
+    else:
+        cc = None
+    httpd = https.WindmillHTTPServer(('0.0.0.0', http_port),
+                                     https.WindmillHTTPRequestHandler, cc,
+                                     apps=[windmill_serv_app, windmill_jsonrpc_app,
+                                     windmill_xmlrpc_app, windmill_compressor_app],
+                                     proxy=https.WindmillHTTPSProxyApplication())
+    add_namespace = httpd.add_namespace
 
     # Attach some objects to httpd for convenience
     httpd.controller_queue = queue
